summaryrefslogtreecommitdiff
path: root/addons/base_geolocalize/models/base_geocoder.py
diff options
context:
space:
mode:
authorXavier Morel <xmo@odoo.com>2019-03-14 14:06:24 +0000
committerXavier Morel <xmo@odoo.com>2019-04-02 09:57:49 +0000
commit1fb20fe3047cf53eff258705d12319015ba96747 (patch)
tree7348a869ed16aa356664b3917c971fe6efbfff1a /addons/base_geolocalize/models/base_geocoder.py
parent27ea18a21b6d2b74b0abb230af1819a0877cff49 (diff)
[IMP] base: try to batch update of children address & commercial fields
With profiling enabled, importing 10k partners, with all of them having the same parent (though not with all of them having the same is_company setting) lowers sync / post-process time from ~550s to ~330s. Put it in an override to _load_records_create so it's only active for imports (which is the original report & test case), use a context key to avoid going the post-processing work in create.
Diffstat (limited to 'addons/base_geolocalize/models/base_geocoder.py')
0 files changed, 0 insertions, 0 deletions